@@ -48,7 +48,7 @@ static void     gdl_dock_paned_get_property   (GObject           *object,
                                                GValue            *value,
                                                GParamSpec        *pspec);
 
-static void     gdl_dock_paned_destroy        (GtkObject         *object);
+static void     gdl_dock_paned_destroy        (GtkWidget         *object);
 
 static void     gdl_dock_paned_add            (GtkContainer      *container,
                                                GtkWidget         *widget);
@@ -93,14 +93,12 @@ static void
 gdl_dock_paned_class_init (GdlDockPanedClass *klass)
 {
     GObjectClass       *g_object_class;
-    GtkObjectClass     *gtk_object_class;
     GtkWidgetClass     *widget_class;
     GtkContainerClass  *container_class;
     GdlDockObjectClass *object_class;
     GdlDockItemClass   *item_class;
 
     g_object_class = G_OBJECT_CLASS (klass);
-    gtk_object_class = GTK_OBJECT_CLASS (klass);
     widget_class = GTK_WIDGET_CLASS (klass);
     container_class = GTK_CONTAINER_CLASS (klass);
     object_class = GDL_DOCK_OBJECT_CLASS (klass);
@@ -110,7 +108,7 @@ gdl_dock_paned_class_init (GdlDockPanedClass *klass)
     g_object_class->get_property = gdl_dock_paned_get_property;
     g_object_class->constructor = gdl_dock_paned_constructor;
     
-    gtk_object_class->destroy = gdl_dock_paned_destroy;
+    widget_class->destroy = gdl_dock_paned_destroy;
 
     container_class->add = gdl_dock_paned_add;
     container_class->forall = gdl_dock_paned_forall;
@@ -197,11 +195,8 @@ gdl_dock_paned_create_child (GdlDockPaned   *paned,
         gtk_widget_unparent (GTK_WIDGET (item->child));
     
     /* create the container paned */
-    if (orientation == GTK_ORIENTATION_HORIZONTAL)
-        item->child = gtk_hpaned_new ();
-    else
-        item->child = gtk_vpaned_new ();
-    
+    item->child = gtk_paned_new (orientation);
+
     /* get notification for propagation */
     g_signal_connect (item->child, "notify::position",
                       (GCallback) gdl_dock_paned_notify_cb, (gpointer) item);
@@ -280,13 +275,14 @@ gdl_dock_paned_get_property (GObject        *object,
 }
 
 static void
-gdl_dock_paned_destroy (GtkObject *object)
+gdl_dock_paned_destroy (GtkWidget *object)
 {
     GdlDockItem *item = GDL_DOCK_ITEM (object);
 
     /* we need to call the virtual first, since in GdlDockDestroy our
        children dock objects are detached */
-    GTK_OBJECT_CLASS (gdl_dock_paned_parent_class)->destroy (object);
+    GTK_WIDGET_CLASS (gdl_dock_paned_parent_class)->destroy (object);
+
 
     /* after that we can remove the GtkNotebook */
     if (item->child) {
